==> dde-network-core_1.0.7.1.orig.tar.xz: dde-network-core-1.0.7.1/dock-network-plugin/translations/dock-network-plugin.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Security Type</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Channel</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primary DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Speed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authenticating</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtaining IP address</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connected</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnected</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtaining address</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Wired Network %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Wireless Network %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connection failed</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Disable wired connection</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Enable wired connection</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disable wireless connection</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Enable wireless connection</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disable network</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Enable network</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Network settings</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.7.orig.tar.xz: dde-network-core-1.1.7/dock-network-plugin/translations/dock-network-plugin.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connect to hidden network</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Connect</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Name (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Security Type</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Channel</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primary DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Speed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authenticating</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtaining IP address</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connected</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnected</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtaining address</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Wired Network %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Wireless Network %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connection failed</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Disable wired connection</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Enable wired connection</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disable wireless connection</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Enable wireless connection</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disable network</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Enable network</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Network settings</translation>
    </message>
</context>
</TS>
